@@ -223,7 +223,7 @@ class Person{
 			$cn = Output::mapUTF8ToASCII($name);
 			$cn = $cn . " " . $this->getEPPN(false);
 		} else {
-			$cn = Input::sanitizePersonName($name);
+			$cn = $name;
 		}
 
 		return $cn;
@@ -367,6 +367,14 @@ class Person{
 	    CS::setSessionKey('CertEmails', $emails);
     }
 
+    /**
+     * Delete the e-mails registered for a user from the sesssion information
+     */
+    public function clearRegCertEmails()
+    {
+        CS::deleteSessionKey('CertEmails');
+    }
+
     private function retrieveRegCertEmails()
     {
 	    $em = CS::getSessionKey('CertEmails');
@@ -378,45 +386,6 @@ class Person{
 		    }
 	    }
     }
-    /**
-     * getSubscriberOrgName() The name of the person's subscriber organization name.
-     *
-     * This is a name of the home-institution, e.g. 'ntnu',  'uio'.
-     *
-     * @return String The subscriber's name.
-     * @deprecated
-     */
-    public function getSubscriberOrgName()
-    {
-	    if (Config::get_config('debug')) {
-		    echo __CLASS__ . "::" . __FUNCTION__ . " " . __FILE__ .
-			    ":".__LINE__. " <font color=\"red\"><b>Deprecated</b></font> ".
-			    "use getSubscriber()->getOrgName() instead<br />\n";
-	    }
-	    Logger::log_event(LOG_DEBUG, __CLASS__ . ":" . __FUNCTION__ . " deprecated");
-	    if (isset($this->subscriber)) {
-		    return $this->subscriber->getOrgName();
-	    }
-	    return "";
-    }
-
-    /**
-     * getSubscriberIdPName() Return the name we use as key in the database.
-     *
-     * @param void
-     * @return String the name of the subscriber used as key in the database.
-     * @deprecated
-     */
-    public function getSubscriberIdPName()
-    {
-	    if (Config::get_config('debug')) {
-		    echo __CLASS__ . "::" . __FUNCTION__ . " " . __FILE__ .":".__LINE__.
-			    " <font color=\"red\"><b>Deprecated</b></font>".
-			    "Use getSubscriber->getIdPName() instead.<br />\n";
-	    }
-	    Logger::log_event(LOG_DEBUG, __CLASS__ . ":" . __FUNCTION__ . " deprecated");
-	    return $this->subscriber->getIdPName();
-    }
 
     /**
      * setEntitlement() store the entitlement
@@ -477,7 +446,7 @@ class Person{
      * testEntitlementAttribute() If a given attribute is part of the entitlement field.
      *
      * @param String The attribute to test for in the supplied entitlement field
-     * @return Boolean $hasAttribute indicating if the queried attribute has been set 
+     * @return Boolean $hasAttribute indicating if the queried attribute has been set
      */
     public function testEntitlementAttribute($attribute)
     {
@@ -884,42 +853,42 @@ class Person{
 
 		if (empty($this->eppn)) {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_reas_malfeppn', 'reasons'));
+			$permission->addReason($translator->getTextForTag('l10n_reas_malfeppn', 'reasons'));
 		}
 
 		if (empty($this->given_name)) {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_reas_nogivenname', 'reasons'));
+			$permission->addReason($translator->getTextForTag('l10n_reas_nogivenname', 'reasons'));
 		}
 
 		if (empty($this->email)) {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_reas_noemailaddr', 'reasons'));
+			$permission->addReason($translator->getTextForTag('l10n_reas_noemailaddr', 'reasons'));
 		}
 
 		if (is_null($this->getNREN()->getCountry()) || $this->getNREN()->getCountry() == "") {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_reas_nocountryname', 'reasons'));
+			$permission->addReason($translator->getTextForTag('l10n_reas_nocountryname', 'reasons'));
 		}
 
 		$subscriberOrgName = $this->subscriber->getOrgName();
 		if (empty($subscriberOrgName)) {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_reas_malfsubsname', 'reasons'));
+			$permission->addReason($translator->getTextForTag('l10n_reas_malfsubsname', 'reasons'));
 		}
 
 		if (Config::get_config('capi_test') &&
 		    Config::get_config('ca_mode') === CA_COMODO &&
 		    $subscriberOrgName == ConfusaConstants::$CAPI_TEST_O_PREFIX) {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_reas_malfsubsname', 'reasons'));
+			$permission->addReason($translator->getTextForTag('l10n_reas_malfsubsname', 'reasons'));
 		}
 
 		if (empty($this->entitlement)
 				|| !$this->testEntitlementAttribute(Config::get_config('entitlement_user'))) {
 			$permission->setPermission(false);
 			$permission->addReason(Config::get_config('entitlement_user') . " " .
-			                       $this->translateTag('l10n_reas_noentitlement', 'reasons'));
+			                       $translator->getTextForTag('l10n_reas_noentitlement', 'reasons'));
 		}
 
 		$query = "SELECT org_state FROM subscribers WHERE name=?";
@@ -931,9 +900,9 @@ class Person{
 
 		if (count($res) == 0) {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_instunkn1', 'reasons') . " " .
+			$permission->addReason($translator->getTextForTag('l10n_instunkn1', 'reasons') . " " .
 			                       $this->subscriber->getIdPName() . " " .
-			                       $this->translateTag('l10n_instunkn2', 'reasons'));
+			                       $translator->getTextForTag('l10n_instunkn2', 'reasons'));
 			return $permission;
 		} else if (count($res) > 1) {
 			throw new CGE_AuthException("More than one DB-entry with same subscriberOrgName " .
@@ -942,9 +911,9 @@ class Person{
 
 		if ($res[0]['org_state'] !== 'subscribed') {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_instnsubscr1', 'reasons') . " " .
+			$permission->addReason($translator->getTextForTag('l10n_instnsubscr1', 'reasons') . " " .
 			                       $this->subscriber->getIdPName() . " " .
-			                       $this->translateTag('l10n_instnsubscr2', 'reasons'));
+			                       $translator->getTextForTag('l10n_instnsubscr2', 'reasons'));
 		}
 
 		return $permission;
